@@ -45,13 +45,13 @@ class ArrowFormat:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ArrowFormat.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ddfbbbe84ff506d91a32384c426ba6d1ea360dcc942cc3c6edb7c1cb93b98a70)
             check_type(argname="argument color", value=color, expected_type=type_hints["color"])
             check_type(argname="argument head", value=head, expected_type=type_hints["head"])
             check_type(argname="argument style", value=style, expected_type=type_hints["style"])
             check_type(argname="argument tail", value=tail, expected_type=type_hints["tail"])
             check_type(argname="argument width", value=width, expected_type=type_hints["width"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "color": color,
             "head": head,
             "style": style,
@@ -151,14 +151,14 @@ class AwsCategoryDefinition:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(AwsCategoryDefinition.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__6d3bc99ca42dc4c3277942bc991eb5b5a10159919dcc4914f9d2657c8c4a4630)
             check_type(argname="argument fill_color", value=fill_color, expected_type=type_hints["fill_color"])
             check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
             check_type(argname="argument variants", value=variants, expected_type=type_hints["variants"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "fill_color": fill_color,
             "gradient_color": gradient_color,
             "id": id,
@@ -233,6 +233,39 @@ class AwsCategoryDefinition:
         )
 
 
+@jsii.enum(jsii_type="@aws-prototyping-sdk/aws-arch.aws_arch.DarkPalette")
+class DarkPalette(enum.Enum):
+    '''(experimental) Dark theme color palette.
+
+    :stability: experimental
+    '''
+
+    PUBLIC = "PUBLIC"
+    '''
+    :stability: experimental
+    '''
+    PRIVATE = "PRIVATE"
+    '''
+    :stability: experimental
+    '''
+    GENERIC = "GENERIC"
+    '''
+    :stability: experimental
+    '''
+    PRIMARY = "PRIMARY"
+    '''
+    :stability: experimental
+    '''
+    SECONDARY = "SECONDARY"
+    '''
+    :stability: experimental
+    '''
+    TERTIARY = "TERTIARY"
+    '''
+    :stability: experimental
+    '''
+
+
 @jsii.enum(jsii_type="@aws-prototyping-sdk/aws-arch.aws_arch.DrawioAws4ParentShapes")
 class DrawioAws4ParentShapes(enum.Enum):
     '''(experimental) Draiwio aws4 parent shapes enum.
@@ -299,7 +332,7 @@ class DrawioAwsShapeStyleBase:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DrawioAwsShapeStyleBase.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__30030fe72953bd413b5dfb1caae3c7a1ad8aa0e8023288f3f1eb8373fb97f2ae)
             check_type(argname="argument align", value=align, expected_type=type_hints["align"])
             check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
             check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
@@ -312,7 +345,7 @@ class DrawioAwsShapeStyleBase:
             check_type(argname="argument vertical_align", value=vertical_align, expected_type=type_hints["vertical_align"])
             check_type(argname="argument vertical_label_position", value=vertical_label_position, expected_type=type_hints["vertical_label_position"])
             check_type(argname="argument pointer_event", value=pointer_event, expected_type=type_hints["pointer_event"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "align": align,
             "aspect": aspect,
             "dashed": dashed,
@@ -482,14 +515,14 @@ class GroupFormat:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GroupFormat.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__8659e43c2e375fa4eba7bdf3d625bb85897544ca73c107aa80d84c5191176699)
             check_type(argname="argument bgcolor", value=bgcolor, expected_type=type_hints["bgcolor"])
             check_type(argname="argument border_color", value=border_color, expected_type=type_hints["border_color"])
             check_type(argname="argument border_style", value=border_style, expected_type=type_hints["border_style"])
             check_type(argname="argument color", value=color, expected_type=type_hints["color"])
             check_type(argname="argument icon_png", value=icon_png, expected_type=type_hints["icon_png"])
             check_type(argname="argument label_location", value=label_location, expected_type=type_hints["label_location"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bgcolor": bgcolor,
             "border_color": border_color,
             "border_style": border_style,
@@ -571,38 +604,6 @@ class LightPalette(enum.Enum):
     :stability: experimental
     '''
 
-    WHITE = "WHITE"
-    '''
-    :stability: experimental
-    '''
-    BLACK = "BLACK"
-    '''
-    :stability: experimental
-    '''
-    BLUE = "BLUE"
-    '''
-    :stability: experimental
-    '''
-    LIGHT_BLUE = "LIGHT_BLUE"
-    '''
-    :stability: experimental
-    '''
-    ORGANGE = "ORGANGE"
-    '''
-    :stability: experimental
-    '''
-    LIGHT_GRAY = "LIGHT_GRAY"
-    '''
-    :stability: experimental
-    '''
-    GREEN = "GREEN"
-    '''
-    :stability: experimental
-    '''
-    YELLOW = "YELLOW"
-    '''
-    :stability: experimental
-    '''
     PUBLIC = "PUBLIC"
     '''
     :stability: experimental
@@ -623,6 +624,150 @@ class LightPalette(enum.Enum):
     '''
     :stability: experimental
     '''
+    TERTIARY = "TERTIARY"
+    '''
+    :stability: experimental
+    '''
+
+
+@jsii.data_type(
+    jsii_type="@aws-prototyping-sdk/aws-arch.aws_arch.ParsedAssetKey",
+    jsii_struct_bases=[],
+    name_mapping={
+        "asset_key": "assetKey",
+        "basename": "basename",
+        "category": "category",
+        "instance_type": "instanceType",
+        "iot_thing": "iotThing",
+        "resource": "resource",
+        "service": "service",
+    },
+)
+class ParsedAssetKey:
+    def __init__(
+        self,
+        *,
+        asset_key: builtins.str,
+        basename: builtins.str,
+        category: builtins.str,
+        instance_type: typing.Optional[builtins.str] = None,
+        iot_thing: typing.Optional[builtins.str] = None,
+        resource: typing.Optional[builtins.str] = None,
+        service: typing.Optional[builtins.str] = None,
+    ) -> None:
+        '''(experimental) Parsed asset key.
+
+        :param asset_key: (experimental) Reference to the full key that was parsed.
+        :param basename: (experimental) The last segment of the key (which is the nested icon). For instances and things this includes the dir prefix.
+        :param category: (experimental) Category id.
+        :param instance_type: (experimental) The instance type if key is for an ec2 instance.
+        :param iot_thing: (experimental) The iot thing if key is for an iot thing.
+        :param resource: (experimental) Resource id if key is for a resource.
+        :param service: (experimental) Service id if key is partitioned by resource.
+
+        :stability: experimental
+        '''
+        if __debug__:
+            type_hints = typing.get_type_hints(_typecheckingstub__b90dcd1992dbdb7888d2294b12034f516795df984206c6607ebcd3fd52724f62)
+            check_type(argname="argument asset_key", value=asset_key, expected_type=type_hints["asset_key"])
+            check_type(argname="argument basename", value=basename, expected_type=type_hints["basename"])
+            check_type(argname="argument category", value=category, expected_type=type_hints["category"])
+            check_type(argname="argument instance_type", value=instance_type, expected_type=type_hints["instance_type"])
+            check_type(argname="argument iot_thing", value=iot_thing, expected_type=type_hints["iot_thing"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
+            check_type(argname="argument service", value=service, expected_type=type_hints["service"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
+            "asset_key": asset_key,
+            "basename": basename,
+            "category": category,
+        }
+        if instance_type is not None:
+            self._values["instance_type"] = instance_type
+        if iot_thing is not None:
+            self._values["iot_thing"] = iot_thing
+        if resource is not None:
+            self._values["resource"] = resource
+        if service is not None:
+            self._values["service"] = service
+
+    @builtins.property
+    def asset_key(self) -> builtins.str:
+        '''(experimental) Reference to the full key that was parsed.
+
+        :stability: experimental
+        '''
+        result = self._values.get("asset_key")
+        assert result is not None, "Required property 'asset_key' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def basename(self) -> builtins.str:
+        '''(experimental) The last segment of the key (which is the nested icon).
+
+        For instances and things this includes the dir prefix.
+
+        :stability: experimental
+        '''
+        result = self._values.get("basename")
+        assert result is not None, "Required property 'basename' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def category(self) -> builtins.str:
+        '''(experimental) Category id.
+
+        :stability: experimental
+        '''
+        result = self._values.get("category")
+        assert result is not None, "Required property 'category' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def instance_type(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The instance type if key is for an ec2 instance.
+
+        :stability: experimental
+        '''
+        result = self._values.get("instance_type")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def iot_thing(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The iot thing if key is for an iot thing.
+
+        :stability: experimental
+        '''
+        result = self._values.get("iot_thing")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def resource(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Resource id if key is for a resource.
+
+        :stability: experimental
+        '''
+        result = self._values.get("resource")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def service(self) -> typing.Optional[builtins.str]:
+        '''(experimental) Service id if key is partitioned by resource.
+
+        :stability: experimental
+        '''
+        result = self._values.get("service")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "ParsedAssetKey(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.data_type(
@@ -640,11 +785,11 @@ class Theme:
     def __init__(
         self,
         *,
-        arrows: typing.Union["ThemeArrows", typing.Dict[str, typing.Any]],
-        backgrounds: typing.Union["ThemeBackgrounds", typing.Dict[str, typing.Any]],
-        groups: typing.Union["ThemeGroups", typing.Dict[str, typing.Any]],
-        id: "ThemesEnum",
-        text: typing.Union["ThemeText", typing.Dict[str, typing.Any]],
+        arrows: typing.Union["ThemeArrows", typing.Dict[builtins.str, typing.Any]],
+        backgrounds: typing.Union["ThemeBackgrounds", typing.Dict[builtins.str, typing.Any]],
+        groups: typing.Union["ThemeGroups", typing.Dict[builtins.str, typing.Any]],
+        id: builtins.str,
+        text: typing.Union["ThemeText", typing.Dict[builtins.str, typing.Any]],
     ) -> None:
         '''(experimental) Theme definition.
 
@@ -665,13 +810,13 @@ class Theme:
         if isinstance(text, dict):
             text = ThemeText(**text)
         if __debug__:
-            type_hints = typing.get_type_hints(Theme.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__22a65172e614ac621fa1434cabbe82b113331f3a0398fee2480f1a9cf5d3993b)
             check_type(argname="argument arrows", value=arrows, expected_type=type_hints["arrows"])
             check_type(argname="argument backgrounds", value=backgrounds, expected_type=type_hints["backgrounds"])
             check_type(argname="argument groups", value=groups, expected_type=type_hints["groups"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
             check_type(argname="argument text", value=text, expected_type=type_hints["text"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "arrows": arrows,
             "backgrounds": backgrounds,
             "groups": groups,
@@ -707,13 +852,13 @@ class Theme:
         return typing.cast("ThemeGroups", result)
 
     @builtins.property
-    def id(self) -> "ThemesEnum":
+    def id(self) -> builtins.str:
         '''
         :stability: experimental
         '''
         result = self._values.get("id")
         assert result is not None, "Required property 'id' is missing"
-        return typing.cast("ThemesEnum", result)
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def text(self) -> "ThemeText":
@@ -750,10 +895,10 @@ class ThemeArrows:
     def __init__(
         self,
         *,
-        child: typing.Union[ArrowFormat, typing.Dict[str, typing.Any]],
-        default: typing.Union[ArrowFormat, typing.Dict[str, typing.Any]],
-        dependency: typing.Union[ArrowFormat, typing.Dict[str, typing.Any]],
-        reference: typing.Union[ArrowFormat, typing.Dict[str, typing.Any]],
+        child: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+        default: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+        dependency: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+        reference: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
     ) -> None:
         '''(experimental) Theme arrow dictionary.
 
@@ -773,12 +918,12 @@ class ThemeArrows:
         if isinstance(reference, dict):
             reference = ArrowFormat(**reference)
         if __debug__:
-            type_hints = typing.get_type_hints(ThemeArrows.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__11672d5bf45c19750018762dfc6f12c5c3c34381a41533c09d9e6155f6c99299)
             check_type(argname="argument child", value=child, expected_type=type_hints["child"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument dependency", value=dependency, expected_type=type_hints["dependency"])
             check_type(argname="argument reference", value=reference, expected_type=type_hints["reference"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "child": child,
             "default": default,
             "dependency": dependency,
@@ -862,12 +1007,12 @@ class ThemeBackgrounds:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ThemeBackgrounds.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__79a4f18d631c73b66dd9be29d4e89b668903f8cba4b8bea16e8021c86f407a49)
             check_type(argname="argument base", value=base, expected_type=type_hints["base"])
             check_type(argname="argument generic", value=generic, expected_type=type_hints["generic"])
             check_type(argname="argument private", value=private, expected_type=type_hints["private"])
             check_type(argname="argument public", value=public, expected_type=type_hints["public"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "base": base,
             "generic": generic,
             "private": private,
@@ -952,26 +1097,26 @@ class ThemeGroups:
     def __init__(
         self,
         *,
-        auto_scaling_group: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        availability_zone: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        aws_account: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        aws_io_t_greengrass: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        aws_io_t_greengrass_deployment: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        aws_step_functions_workflow: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        cloud: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        cloud_alt: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        corporate_data_center: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        ec2_instance_contents: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        elastic_beanstalk_container: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        generic: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        generic_alt: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        private_subnet: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        public_subnet: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        region: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        security_group: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        server_contents: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        spot_fleet: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
-        vpc: typing.Union[GroupFormat, typing.Dict[str, typing.Any]],
+        auto_scaling_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        availability_zone: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        aws_account: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        aws_io_t_greengrass: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        aws_io_t_greengrass_deployment: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        aws_step_functions_workflow: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        cloud: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        cloud_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        corporate_data_center: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        ec2_instance_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        elastic_beanstalk_container: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        generic: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        generic_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        private_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        public_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        region: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        security_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        server_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        spot_fleet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+        vpc: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
     ) -> None:
         '''(experimental) Theme group dicionary.
 
@@ -1039,7 +1184,7 @@ class ThemeGroups:
         if isinstance(vpc, dict):
             vpc = GroupFormat(**vpc)
         if __debug__:
-            type_hints = typing.get_type_hints(ThemeGroups.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__bc0e874b2050a403180b581f6eedf5b4f8443e2a4ec92851930697997434b323)
             check_type(argname="argument auto_scaling_group", value=auto_scaling_group, expected_type=type_hints["auto_scaling_group"])
             check_type(argname="argument availability_zone", value=availability_zone, expected_type=type_hints["availability_zone"])
             check_type(argname="argument aws_account", value=aws_account, expected_type=type_hints["aws_account"])
@@ -1060,7 +1205,7 @@ class ThemeGroups:
             check_type(argname="argument server_contents", value=server_contents, expected_type=type_hints["server_contents"])
             check_type(argname="argument spot_fleet", value=spot_fleet, expected_type=type_hints["spot_fleet"])
             check_type(argname="argument vpc", value=vpc, expected_type=type_hints["vpc"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "auto_scaling_group": auto_scaling_group,
             "availability_zone": availability_zone,
             "aws_account": aws_account,
@@ -1282,6 +1427,7 @@ class ThemeGroups:
         "default": "default",
         "primary": "primary",
         "secondary": "secondary",
+        "tertiary": "tertiary",
     },
 )
 class ThemeText:
@@ -1291,24 +1437,28 @@ class ThemeText:
         default: builtins.str,
         primary: builtins.str,
         secondary: builtins.str,
+        tertiary: builtins.str,
     ) -> None:
         '''(experimental) Theme text dictionary.
 
         :param default: 
         :param primary: 
         :param secondary: 
+        :param tertiary: 
 
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ThemeText.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e6cbf0046f749727038ac22da7cfe76b19721461e35bf23487ba22bb90277aac)
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument primary", value=primary, expected_type=type_hints["primary"])
             check_type(argname="argument secondary", value=secondary, expected_type=type_hints["secondary"])
-        self._values: typing.Dict[str, typing.Any] = {
+            check_type(argname="argument tertiary", value=tertiary, expected_type=type_hints["tertiary"])
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "default": default,
             "primary": primary,
             "secondary": secondary,
+            "tertiary": tertiary,
         }
 
     @builtins.property
@@ -1338,6 +1488,15 @@ class ThemeText:
         assert result is not None, "Required property 'secondary' is missing"
         return typing.cast(builtins.str, result)
 
+    @builtins.property
+    def tertiary(self) -> builtins.str:
+        '''
+        :stability: experimental
+        '''
+        result = self._values.get("tertiary")
+        assert result is not None, "Required property 'tertiary' is missing"
+        return typing.cast(builtins.str, result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -1350,19 +1509,6 @@ class ThemeText:
         )
 
 
-@jsii.enum(jsii_type="@aws-prototyping-sdk/aws-arch.aws_arch.ThemesEnum")
-class ThemesEnum(enum.Enum):
-    '''(experimental) Enum of available themes.
-
-    :stability: experimental
-    '''
-
-    LIGHT = "LIGHT"
-    '''
-    :stability: experimental
-    '''
-
-
 @jsii.data_type(
     jsii_type="@aws-prototyping-sdk/aws-arch.aws_arch.DrawioAwsResourceIconStyleBase",
     jsii_struct_bases=[DrawioAwsShapeStyleBase],
@@ -1425,7 +1571,7 @@ class DrawioAwsResourceIconStyleBase(DrawioAwsShapeStyleBase):
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DrawioAwsResourceIconStyleBase.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__33ca7bd53c2980c0508df96383dc6a8070baf0896ad2b8cd144f7a49663a854b)
             check_type(argname="argument align", value=align, expected_type=type_hints["align"])
             check_type(argname="argument aspect", value=aspect, expected_type=type_hints["aspect"])
             check_type(argname="argument dashed", value=dashed, expected_type=type_hints["dashed"])
@@ -1441,7 +1587,7 @@ class DrawioAwsResourceIconStyleBase(DrawioAwsShapeStyleBase):
             check_type(argname="argument fill_color", value=fill_color, expected_type=type_hints["fill_color"])
             check_type(argname="argument font_color", value=font_color, expected_type=type_hints["font_color"])
             check_type(argname="argument gradient_color", value=gradient_color, expected_type=type_hints["gradient_color"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "align": align,
             "aspect": aspect,
             "dashed": dashed,
@@ -1609,17 +1755,18 @@ class DrawioAwsResourceIconStyleBase(DrawioAwsShapeStyleBase):
 __all__ = [
     "ArrowFormat",
     "AwsCategoryDefinition",
+    "DarkPalette",
     "DrawioAws4ParentShapes",
     "DrawioAwsResourceIconStyleBase",
     "DrawioAwsShapeStyleBase",
     "GroupFormat",
     "LightPalette",
+    "ParsedAssetKey",
     "Theme",
     "ThemeArrows",
     "ThemeBackgrounds",
     "ThemeGroups",
     "ThemeText",
-    "ThemesEnum",
     "drawio_spec",
     "pricing_manifest",
 ]
@@ -1629,3 +1776,157 @@ publication.publish()
 # Loading modules to ensure their types are registered with the jsii runtime library
 from . import drawio_spec
 from . import pricing_manifest
+
+def _typecheckingstub__ddfbbbe84ff506d91a32384c426ba6d1ea360dcc942cc3c6edb7c1cb93b98a70(
+    *,
+    color: typing.Union[builtins.str, builtins.bool],
+    head: builtins.str,
+    style: builtins.str,
+    tail: builtins.str,
+    width: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6d3bc99ca42dc4c3277942bc991eb5b5a10159919dcc4914f9d2657c8c4a4630(
+    *,
+    fill_color: builtins.str,
+    gradient_color: builtins.str,
+    id: builtins.str,
+    name: builtins.str,
+    font_color: typing.Optional[builtins.str] = None,
+    variants: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__30030fe72953bd413b5dfb1caae3c7a1ad8aa0e8023288f3f1eb8373fb97f2ae(
+    *,
+    align: builtins.str,
+    aspect: builtins.str,
+    dashed: jsii.Number,
+    font_size: jsii.Number,
+    font_style: typing.Union[builtins.str, jsii.Number],
+    gradient_direction: builtins.str,
+    html: jsii.Number,
+    outline_connect: jsii.Number,
+    stroke_color: builtins.str,
+    vertical_align: builtins.str,
+    vertical_label_position: builtins.str,
+    pointer_event: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8659e43c2e375fa4eba7bdf3d625bb85897544ca73c107aa80d84c5191176699(
+    *,
+    bgcolor: typing.Union[builtins.str, builtins.bool],
+    border_color: typing.Union[builtins.str, builtins.bool],
+    border_style: builtins.str,
+    color: typing.Union[builtins.str, builtins.bool],
+    icon_png: typing.Optional[builtins.str] = None,
+    label_location: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b90dcd1992dbdb7888d2294b12034f516795df984206c6607ebcd3fd52724f62(
+    *,
+    asset_key: builtins.str,
+    basename: builtins.str,
+    category: builtins.str,
+    instance_type: typing.Optional[builtins.str] = None,
+    iot_thing: typing.Optional[builtins.str] = None,
+    resource: typing.Optional[builtins.str] = None,
+    service: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__22a65172e614ac621fa1434cabbe82b113331f3a0398fee2480f1a9cf5d3993b(
+    *,
+    arrows: typing.Union[ThemeArrows, typing.Dict[builtins.str, typing.Any]],
+    backgrounds: typing.Union[ThemeBackgrounds, typing.Dict[builtins.str, typing.Any]],
+    groups: typing.Union[ThemeGroups, typing.Dict[builtins.str, typing.Any]],
+    id: builtins.str,
+    text: typing.Union[ThemeText, typing.Dict[builtins.str, typing.Any]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11672d5bf45c19750018762dfc6f12c5c3c34381a41533c09d9e6155f6c99299(
+    *,
+    child: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+    default: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+    dependency: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+    reference: typing.Union[ArrowFormat, typing.Dict[builtins.str, typing.Any]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__79a4f18d631c73b66dd9be29d4e89b668903f8cba4b8bea16e8021c86f407a49(
+    *,
+    base: builtins.str,
+    generic: builtins.str,
+    private: builtins.str,
+    public: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__bc0e874b2050a403180b581f6eedf5b4f8443e2a4ec92851930697997434b323(
+    *,
+    auto_scaling_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    availability_zone: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    aws_account: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    aws_io_t_greengrass: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    aws_io_t_greengrass_deployment: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    aws_step_functions_workflow: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    cloud: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    cloud_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    corporate_data_center: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    ec2_instance_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    elastic_beanstalk_container: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    generic: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    generic_alt: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    private_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    public_subnet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    region: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    security_group: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    server_contents: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    spot_fleet: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+    vpc: typing.Union[GroupFormat, typing.Dict[builtins.str, typing.Any]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e6cbf0046f749727038ac22da7cfe76b19721461e35bf23487ba22bb90277aac(
+    *,
+    default: builtins.str,
+    primary: builtins.str,
+    secondary: builtins.str,
+    tertiary: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__33ca7bd53c2980c0508df96383dc6a8070baf0896ad2b8cd144f7a49663a854b(
+    *,
+    align: builtins.str,
+    aspect: builtins.str,
+    dashed: jsii.Number,
+    font_size: jsii.Number,
+    font_style: typing.Union[builtins.str, jsii.Number],
+    gradient_direction: builtins.str,
+    html: jsii.Number,
+    outline_connect: jsii.Number,
+    stroke_color: builtins.str,
+    vertical_align: builtins.str,
+    vertical_label_position: builtins.str,
+    pointer_event: typing.Optional[jsii.Number] = None,
+    fill_color: builtins.str,
+    font_color: builtins.str,
+    gradient_color: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
